@@ -113,6 +113,9 @@ MSG_FORWARD = b"FRWD"
 MSG_ABORT = b"ABT"
 MSG_PROGRESS = b"PROG"
 
+OPEN_LOOP = "Open loop"
+CLOSE_LOOP = "Close loop"
+
 PROXY = "PROXY"
 
 # Session groups
@@ -153,17 +156,18 @@ ATTR_ERROR_CODE = u"Error code"
 ATTR_LATENCY = u"Latency"
 ATTR_MODULES = u"Modules count"
 ATTR_STATE = u"State"
-ATTR_ENCODER_BASE_UNIT = u"Enc. base unit"
+ATTR_ENCODER_BASE_UNIT = u"Enc base unit"
 ATTR_HAND_TOOL = u"Hand tool"
 ATTR_MOVEMENT_LOCKED = u"Movement locked"
 ATTR_INTERNAL_COMM_FAILURE = u"Comm failure"
 ATTR_STREAMING = u"Streaming"
+ATTR_HOLDING = u"Holding"
 ATTR_SENSOR_PRESENT = u"Sensor present"
 ATTR_BOOSTER_PRESENT = u"Booster present"
 ATTR_ADJUSTMENT_ACTIVE = u"Adjustment active"
 ATTR_IOM_PRESENT = u"I/O present"
-ATTR_HIGH_VOLTAGE_FAILURE = u"High vol. failure"
-ATTR_HIGH_VOLTAGE_OVERLOAD = u"High vol. overload"
+ATTR_HIGH_VOLTAGE_FAILURE = u"High voltage failure"
+ATTR_HIGH_VOLTAGE_OVERLOAD = u"High voltage overload"
 ATTR_OVER_TEMPERATURE = u"Over temperature"
 ATTR_CLOSED_LOOP_ACTIVE = u"Closed loop active"
 ATTR_CALIBRATING = u"Calibrating"
@@ -363,6 +367,7 @@ ATTR_FAST_REFERENCE_VELOCITY = u"Fast reference velocity"
 ATTR_SLOW_REFERENCE_VELOCITY = u"Slow reference velocity"
 ATTR_REFERENCE_STEPS_BACK = u"Reference steps back"
 ATTR_HOLDING_TIME = u"Holding time"
+ATTR_STEPS = u"Steps"
 ATTR_PRESSURE = u"Pressure"
 ATTR_POWER = u"Power"
 ATTR_CURRENT_SAMPLE = u"Current sample"
@@ -455,12 +460,12 @@ ATTR_AUTH_TOKEN = u"Auth token"
 ATTR_USER_NAME = u"username"
 ATTR_PASSWORD = u"Password"
 
-ATTR_ANALOGUE_PROGRAMMING_ACTIVE = u"Analogue prog. active"
+ATTR_ANALOGUE_PROGRAMMING_ACTIVE = u"Analogue prog active"
 ATTR_CALIBRATION_MODE = u"Calibration mode"
 ATTR_CONTROL_CURRENT = u"Control current"
 ATTR_CONTROL_VOLTAGE = u"Control voltage"
 ATTR_CURRENT_RAMPING_RATE = u"Current ramping rate"
-ATTR_DIGITAL_PROGRAMMING_ACTIVE = u"Digital prog. active"
+ATTR_DIGITAL_PROGRAMMING_ACTIVE = u"Digital prog active"
 ATTR_MONITORED_CURRENT = u"I-Mon"
 ATTR_MONITORED_VOLTAGE = u"V-Mon"
 ATTR_OUTPUT_POLARITY = u"Output polarity"
@@ -523,7 +528,7 @@ ATTR_STREAM_READOUT = "Stream readout"
 ATTR_VALUE_READOUT = "Value readout"
 ATTR_STREAMABLE = "Streamable"
 ATTR_FULL_ACCESS = "Full access"
-ATTR_PILOT_LASER = "Pilot lasser"
+ATTR_PILOT_LASER = "Pilot laser"
 ATTR_IS_STABLE = "Is stable"
 ATTR_CAPTURE_REGION = "Capture region"
 ATTR_FourCC_CODEC = "FourCC Codec"
@@ -536,3 +541,13 @@ ATTR_BUFFERS_INTERLEAVED = "Buffers interleaved"
 ATTR_FILTER_RATE = "Filter rate"
 ATTR_BUFFERS_COUNT = "Buffers count"
 ATTR_FRAMES_GRABBED = "Frames grabbed"
+ATTR_HEAD_FIBER_LENGTH = "Head fiber length"
+ATTR_EXTENSION_FIBER_LENGTH = "Extension fiber length"
+ATTR_HEAD_TYPE = "Head type"
+ATTR_MIN_WORKING_DISTANCE = "Min working distance"
+ATTR_MAX_WORKING_DISTANCE = "Max working distance"
+ATTR_BEAM_INTERRUPT_TOLERANCE = "Beam interrupt tolerance"
+ATTR_CLOSE_LOOP_UNIT = "Close loop unit"
+ATTR_CLOSE_LOOP_FACTOR = "Close loop factor"
+ATTR_MOVE_METHOD = "Move method"
+ATTR_CHANNEL_ENABLED = "Channel enabled"
\ No newline at end of file
