@@ -10,6 +10,7 @@ import serial
 from kamzik3.snippets.snippetsDecorators import expose_method
 from pint import UndefinedUnitError, DimensionalityError
 
+import oyaml as yaml
 import kamzik3
 from kamzik3 import WriteException, CommandFormatException, DeviceError
 from kamzik3.constants import *
@@ -163,7 +164,7 @@ class Device(Subject, YamlSerializable):
             if group not in self.attributes:
                 self.attributes[group] = {}
             self.attributes[group][name] = attribute
-        if kamzik3.session.publisher is not None:
+        if  kamzik3.session.publisher is not None:
             header = "{}.{}".format(attribute.attribute_id, TOKEN_ATTRIBUTE_REPLACE)
             kamzik3.session.publisher.push_message(header, attribute)
         return attribute
@@ -996,4 +997,10 @@ class Device(Subject, YamlSerializable):
         reconnect function, but visible to client.
         """
         self.reconnect()
-       
\ No newline at end of file
+
+    @expose_method()
+    def get_config(self):
+        """
+        This function return Device configuration.
+        """
+        return yaml.dump(self.config, Dumper=yaml.Dumper)
\ No newline at end of file
