@@ -47,23 +47,23 @@ class DeviceGalil(DeviceSocket):
 
         self.create_attribute(ATTR_MODEL, default_value="", readonly=True)
 
-        self["Analog input"] = {}
-        self["Analog output"] = {}
-        self["Digital input"] = {}
-        self["Digital output"] = {}
+        self[ATTR_ANALOG_INPUT] = {}
+        self[ATTR_ANALOG_OUTPUT] = {}
+        self[ATTR_DIGITAL_INPUT] = {}
+        self[ATTR_DIGITAL_OUTPUT] = {}
 
         for i in range(8):
-            self.create_attribute(self.AI_config[i], "Analog input", unit=u"V",
+            self.create_attribute(self.AI_config[i], ATTR_ANALOG_INPUT, unit=u"V",
                                   default_type=np.float16, decimals=4, readonly=True)
-            self.create_attribute(self.AO_config[i], "Analog output", unit=u"V",
+            self.create_attribute(self.AO_config[i], ATTR_ANALOG_OUTPUT, unit=u"V",
                                   set_function=lambda value, output=i: self.set_analog_output(output, value),
                                   default_type=np.float16, decimals=4)
-            self.create_attribute(self.DI_config[i], "Digital input", default_type=np.bool, readonly=True)
-            self.create_attribute(self.DI_config[8 + i], "Digital input", default_type=np.bool, readonly=True)
-            self.create_attribute(self.DO_config[i], "Digital output", default_type=np.bool,
+            self.create_attribute(self.DI_config[i], ATTR_DIGITAL_INPUT, default_type=np.bool, readonly=True)
+            self.create_attribute(self.DI_config[8 + i], ATTR_DIGITAL_INPUT, default_type=np.bool, readonly=True)
+            self.create_attribute(self.DO_config[i], ATTR_DIGITAL_OUTPUT, default_type=np.bool,
                                   set_value_when_set_function=False,
                                   set_function=lambda value, output=i: self.set_digital_output(output, value))
-            self.create_attribute(self.DO_config[8 + i], "Digital output", default_type=np.bool,
+            self.create_attribute(self.DO_config[8 + i], ATTR_DIGITAL_OUTPUT, default_type=np.bool,
                                   set_value_when_set_function=False,
                                   set_function=lambda value, output=8 + i: self.set_digital_output(output, value))
 
@@ -138,20 +138,20 @@ class DeviceGalil(DeviceSocket):
             model_name, revision = self.get_value(ATTR_MODEL).split(" ", maxsplit=1)
             if model_name == u"RIO47100":
                 for index, ao in enumerate(np.frombuffer(data[8:24], dtype=self.analog_output_date_type)[0]):
-                    ao_attribute = self["Analog output"][self.AO_config[index]]
+                    ao_attribute = self[ATTR_ANALOG_OUTPUT][self.AO_config[index]]
                     ao_min, ao_max = ao_attribute.remove_offset_factor(
                         ao_attribute[MIN]), ao_attribute.remove_offset_factor(ao_attribute[MAX])
                     dt_info = np.iinfo(self.analog_output_date_type[index])
-                    self.set_raw_value(("Analog output", self.AO_config[index]),
+                    self.set_raw_value((ATTR_ANALOG_OUTPUT, self.AO_config[index]),
                                        (((ao - dt_info.min) * (ao_max - ao_min)) / (
                                                dt_info.max - dt_info.min)) + ao_min)
 
                 for index, ai in enumerate(np.frombuffer(data[24:40], dtype=self.analog_input_date_type)[0]):
-                    ai_attribute = self["Analog input"][self.AI_config[index]]
+                    ai_attribute = self[ATTR_ANALOG_INPUT][self.AI_config[index]]
                     ai_min, ai_max = ai_attribute.remove_offset_factor(
                         ai_attribute[MIN]), ai_attribute.remove_offset_factor(ai_attribute[MAX])
                     dt_info = np.iinfo(self.analog_input_date_type[index])
-                    self.set_raw_value(("Analog input", self.AI_config[index]),
+                    self.set_raw_value((ATTR_ANALOG_INPUT, self.AI_config[index]),
                                        (((ai - dt_info.min) * (ai_max - ai_min)) / (
                                                dt_info.max - dt_info.min)) + ai_min)
 
@@ -162,9 +162,9 @@ class DeviceGalil(DeviceSocket):
                 digital_input = [bool(int(x)) for x in reversed(digital_input)] + ([False] * (16 - len(digital_input)))
 
                 for i, do in enumerate(digital_output):
-                    self.set_raw_value(["Digital output", self.DO_config[i]], do)
+                    self.set_raw_value([ATTR_DIGITAL_OUTPUT, self.DO_config[i]], do)
                 for i, di in enumerate(digital_input):
-                    self.set_raw_value(["Digital input", self.DI_config[i]], di)
+                    self.set_raw_value([ATTR_DIGITAL_INPUT, self.DI_config[i]], di)
         except ValueError:
             pass
 
@@ -187,18 +187,18 @@ class DeviceGalil(DeviceSocket):
         elif command == self.analog_input_readout_command:
             analog_inputs = map(float, output.split())
             for i, value in enumerate(analog_inputs):
-                self.set_raw_value(("Analog input", self.AI_config[i]), value)
+                self.set_raw_value((ATTR_ANALOG_INPUT, self.AI_config[i]), value)
         elif command == self.analog_output_readout_command:
             analog_outputs = map(float, output.split())
             for i, value in enumerate(analog_outputs):
-                self.set_raw_value(("Analog output", self.AO_config[i]), value)
+                self.set_raw_value((ATTR_ANALOG_OUTPUT, self.AO_config[i]), value)
         elif command == self.digital_lO_readout_command:
             di0, di1, do0, do1 = map(lambda v: int(float(v)), output.split())
             for bit in range(8):
-                self.set_raw_value(("Digital input", self.DI_config[bit]), bool(di0 & (1 << bit)))
-                self.set_raw_value(("Digital input", self.DI_config[8 + bit]), bool(di1 & (1 << bit)))
-                self.set_raw_value(("Digital output", self.DO_config[bit]), bool(do0 & (1 << bit)))
-                self.set_raw_value(("Digital output", self.DO_config[8 + bit]), bool(do1 & (1 << bit)))
+                self.set_raw_value((ATTR_DIGITAL_INPUT, self.DI_config[bit]), bool(di0 & (1 << bit)))
+                self.set_raw_value((ATTR_DIGITAL_INPUT, self.DI_config[8 + bit]), bool(di1 & (1 << bit)))
+                self.set_raw_value((ATTR_DIGITAL_OUTPUT, self.DO_config[bit]), bool(do0 & (1 << bit)))
+                self.set_raw_value((ATTR_DIGITAL_OUTPUT, self.DO_config[8 + bit]), bool(do1 & (1 << bit)))
         elif command == "ID;":
             for line in output.split("\r\n"):
                 if line.startswith("analog inputs"):
@@ -209,10 +209,10 @@ class DeviceGalil(DeviceSocket):
                         if values is not None:
                             first_input, last_input, min_value, max_value = values.group(1), values.group(2), values.group(3), values.group(4)
                             for index in range(int(first_input), int(last_input) + 1):
-                                if self.get_attribute(("Analog input", self.AI_config[index], MIN)) in (None, np.inf, -np.inf):
-                                    self.set_raw_value(("Analog input", self.AI_config[index]), float(min_value), key=MIN)
-                                if self.get_attribute(("Analog input", self.AI_config[index], MAX)) in (None, np.inf, -np.inf):
-                                    self.set_raw_value(("Analog input", self.AI_config[index]), float(max_value), key=MAX)
+                                if self.get_attribute((ATTR_ANALOG_INPUT, self.AI_config[index], MIN)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value((ATTR_ANALOG_INPUT, self.AI_config[index]), float(min_value), key=MIN)
+                                if self.get_attribute((ATTR_ANALOG_INPUT, self.AI_config[index], MAX)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value((ATTR_ANALOG_INPUT, self.AI_config[index]), float(max_value), key=MAX)
                 if line.startswith("analog outputs"):
                     if "programmable range" in line:
                         self.command(self.analog_output_limits_command)
@@ -221,10 +221,10 @@ class DeviceGalil(DeviceSocket):
                         if values is not None:
                             first_input, last_input, min_value, max_value = values.group(1), values.group(2), values.group(3), values.group(4)
                             for index in range(int(first_input), int(last_input) + 1):
-                                if self.get_attribute(("Analog output", self.AO_config[index], MIN)) in (None, np.inf, -np.inf):
-                                    self.set_raw_value(("Analog output", self.AO_config[index]), float(min_value), key=MIN)
-                                if self.get_attribute(("Analog output", self.AO_config[index], MAX)) in (None, np.inf, -np.inf):
-                                    self.set_raw_value(("Analog output", self.AO_config[index]), float(max_value), key=MAX)
+                                if self.get_attribute((ATTR_ANALOG_OUTPUT, self.AO_config[index], MIN)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value((ATTR_ANALOG_OUTPUT, self.AO_config[index]), float(min_value), key=MIN)
+                                if self.get_attribute((ATTR_ANALOG_OUTPUT, self.AO_config[index], MAX)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value((ATTR_ANALOG_OUTPUT, self.AO_config[index]), float(max_value), key=MAX)
         elif command == "\x12\x16;":
             self.set_raw_value(ATTR_MODEL, output)
         elif command == self.analog_output_limits_command:
@@ -240,10 +240,10 @@ class DeviceGalil(DeviceSocket):
                 # Append tuple representing analog output data type
                 new_date_type.append((self.AO_config[index], dt))
                 # Set both limits for analog channel
-                if self.get_attribute(("Analog output", self.AO_config[index], MIN)) in (None, np.inf, -np.inf):
-                    self.set_raw_value(("Analog output", self.AO_config[index]), lower_limit, key=MIN)
-                if self.get_attribute(("Analog output", self.AO_config[index], MAX)) in (None, np.inf, -np.inf):
-                    self.set_raw_value(("Analog output", self.AO_config[index]), upper_limit, key=MAX)
+                if self.get_attribute((ATTR_ANALOG_OUTPUT, self.AO_config[index], MIN)) in (None, np.inf, -np.inf):
+                    self.set_raw_value((ATTR_ANALOG_OUTPUT, self.AO_config[index]), lower_limit, key=MIN)
+                if self.get_attribute((ATTR_ANALOG_OUTPUT, self.AO_config[index], MAX)) in (None, np.inf, -np.inf):
+                    self.set_raw_value((ATTR_ANALOG_OUTPUT, self.AO_config[index]), upper_limit, key=MAX)
             # Set numpy data type, which is used to parse binary UDP readout
             self.analog_output_date_type = np.dtype(new_date_type)
         elif command == self.analog_input_limits_command:
@@ -259,10 +259,10 @@ class DeviceGalil(DeviceSocket):
                 # Append tuple representing analog output data type
                 new_date_type.append((self.AO_config[index], dt))
                 # Set both limits for analog channel
-                if self.get_attribute(("Analog input", self.AI_config[index], MIN)) in (None, np.inf, -np.inf):
-                    self.set_raw_value(("Analog input", self.AI_config[index]), lower_limit, key=MIN)
-                if self.get_attribute(("Analog input", self.AI_config[index], MAX)) in (None, np.inf, -np.inf):
-                    self.set_raw_value(("Analog input", self.AI_config[index]), upper_limit, key=MAX)
+                if self.get_attribute((ATTR_ANALOG_INPUT, self.AI_config[index], MIN)) in (None, np.inf, -np.inf):
+                    self.set_raw_value((ATTR_ANALOG_INPUT, self.AI_config[index]), lower_limit, key=MIN)
+                if self.get_attribute((ATTR_ANALOG_INPUT, self.AI_config[index], MAX)) in (None, np.inf, -np.inf):
+                    self.set_raw_value((ATTR_ANALOG_INPUT, self.AI_config[index]), upper_limit, key=MAX)
             # Set numpy data type, which is used to parse binary UDP readout
             self.analog_input_date_type = np.dtype(new_date_type)
 
