@@ -333,17 +333,15 @@ class DeviceTangoEigerDetector(DeviceTango):
                               description="Internal frame counter",
                               default_type=np.uint64, min_value=0)
 
-    @expose_method()
-    def reset_frame_counter(self):
-        pass
-
     @expose_method(
         {"Name": "FilePrefix", "Exposure": "FrameTime", "Frames": "Nimages"})
     def acquire_frame(self, Name, Exposure, Frames):
+        self.logger.info(f"Acquisition of {Frames} @ {Exposure} has started.")
         now = datetime.datetime.now()
         Frames = device_units(self, "Nimages", Frames).m
         self.set_attribute(["TriggerMode", VALUE], 3)
         path = os.path.join(self.get_value("shotDir"), f"{Name}_{self.device_id}_{now.strftime('%Y-%m-%d_%H:%M:%S')}")
+        self.set_attribute(["FileWriter", "Mode", VALUE], 1)
         self.set_attribute(["FileWriter", "NamePattern", VALUE], path)
         self.set_attribute(["FileWriter", "NimagesPerFile", VALUE], int(Frames))
         Exposure = device_units(self, "FrameTime", Exposure).m
@@ -369,7 +367,7 @@ class DeviceTangoEigerDetector(DeviceTango):
         if Frames != self.get_value("Nimages"):
             self.set_attribute(["Nimages", VALUE], Frames)
             self.set_attribute(["FileWriter", "NimagesPerFile", VALUE], int(Frames))
-
+        self.set_attribute(["FileWriter", "Mode", VALUE], 1)
         self.set_attribute(["FileWriter", "NamePattern", VALUE],
                            self.get_value("scanFilenamePattern").replace("{$ATTR_FRAME_COUNT}",
                                                                          f"{self.get_value(ATTR_FRAME_COUNT):08d}"))
@@ -377,7 +375,26 @@ class DeviceTangoEigerDetector(DeviceTango):
         self.Trigger()
         self.set_value(ATTR_FRAME_COUNT, self.get_value(ATTR_FRAME_COUNT) + int(Frames))
 
+    @expose_method(
+        {"Exposure": "FrameTime"})
+    def live_view(self, Exposure):
+        self.logger.info(f"Live view has started.")
+        self.set_attribute(["TriggerMode", VALUE], 3)
+        self.set_attribute(["FileWriter", "Mode", VALUE], 0)
+        self.set_attribute(["FileWriter", "NimagesPerFile", VALUE], 1000000)
+        Exposure = device_units(self, "FrameTime", Exposure).m
+        # According to Jan 10ms is lowest frame time
+        frame_time = 10e-3 if Exposure < 10e-3 else Exposure
+        self.set_attribute(["FrameTime", VALUE], frame_time)
+        self.set_attribute(["CountTime", VALUE], float(Exposure))
+        self.set_attribute(["Ntrigger", VALUE], int(1))
+        self.set_attribute(["Nimages", VALUE], 1000000)
+        self.Arm()
+        self.Trigger()
+        self.set_value(ATTR_FRAME_COUNT, self.get_value(ATTR_FRAME_COUNT) + 1000000)
+
     @expose_method()
     def stop(self):
         if self.get_value(ATTR_STATUS) == STATUS_BUSY:
+            self.logger.info(f"Acquisition aborted")
             self.Abort()
