@@ -1,5 +1,6 @@
 import time
 from threading import Thread
+from time import sleep
 
 from kamzik3 import DeviceError, units
 from kamzik3.constants import *
@@ -11,6 +12,8 @@ from kamzik3.snippets.snippetsDecorators import expose_method
 
 class DeviceVirtual(Device, Observer):
 
+    configured = False
+
     def __init__(self, device_list, attribute_list, device_id=None, config=None):
         assert isinstance(device_list, list)
         assert isinstance(attribute_list, list)
@@ -19,6 +22,15 @@ class DeviceVirtual(Device, Observer):
         self.executed_step = None
         self.attached_callbacks = []
         super().__init__(device_id, config)
+        for device in self.device_list:
+            device.attach_attribute_callback(ATTR_STATUS, self.devices_status_update, key_filter=VALUE)
+
+    def devices_status_update(self, value):
+        if self.configured:
+            return
+        for device in self.device_list:
+            if not device.in_statuses(READY_DEVICE_STATUSES):
+                return
         self.connect()
 
     def connect(self, *args):
@@ -37,21 +49,22 @@ class DeviceVirtual(Device, Observer):
 
     def handle_configuration(self):
         start_at = time.time()
+        self.configured = True
+        for device, attribute, callback in self.attached_callbacks:
+            device.detach_attribute_callback(ATTR_STATUS, self.devices_status_update)
+
         for device in self.device_list:
             device.attach_observer(self)
 
         for attribute in self.attribute_list:
             device_attribute = self.device_list[0].get_attribute(attribute).attribute_copy()
-            device_attribute.set_value_when_set_function = False
-            device_attribute.set_function = lambda value, callback, attr=attribute: self._set_attribute_value(attr,
-                                                                                                              value,
-                                                                                                              callback)
-            self.attributes[attribute] = device_attribute
+            device_attribute.set_value_when_set_function = True
+            device_attribute.set_function = lambda value, attr=attribute: self._set_attribute_value(attr, value)
+            self.add_attribute(attribute, device_attribute)
 
-            def callback(key, value, attr=attribute):
-                self.attribute_changed(attr, key, value)
-
-            self.device_list[0].attach_attribute_callback(attribute, callback)
+            def callback(value, attr=attribute):
+                self.attribute_changed(attr, value)
+            self.device_list[0].attach_attribute_callback(attribute, callback, key_filter=VALUE)
             self.attached_callbacks.append((self.device_list[0], attribute, callback))
 
         self._config_commands()
@@ -68,7 +81,7 @@ class DeviceVirtual(Device, Observer):
             raise
 
     def set_absolute_value(self, attribute, value):
-        value_delta = value - self.get_value(attribute)
+        value_delta = value - self.device_list[0].get_value(attribute)
         self.set_relative_value(attribute, units.Quantity(value_delta, self.get_attribute(attribute)[UNIT]))
 
     def set_relative_value(self, attribute, value):
@@ -112,9 +125,8 @@ class DeviceVirtual(Device, Observer):
         group_status = STATUSES_PRIORITY[min(status_priorities)]
         self.set_status(group_status)
 
-    def attribute_changed(self, attribute, key, value):
-        if key == VALUE:
-            self.set_value(attribute, value)
+    def attribute_changed(self, attribute, value):
+        self.set_raw_value(attribute, value)
 
     @expose_method()
     def stop(self):
