@@ -25,7 +25,7 @@ class AttributePlot(pg.PlotWidget, YamlSerializable):
         self.y_buffer = collections.deque([], maxlen=buffer_size)
         try:
             self.base_unit = kwargs.get("unit", attribute[UNIT])
-        except TypeError:
+        except (TypeError, KeyError):
             self.base_unit = ""
 
         pen1 = pg.mkPen(color=(0, 0, 255))
@@ -128,7 +128,8 @@ class DeviceAttributePlot(DeviceWidget):
             self.kwargs["top_label"] = self.device.device_id
         if self.kwargs.get("left_label") == "auto":
             self.kwargs["left_label"] = self.attribute
-        attribute_plot = AttributePlot(attribute, 3600, plot=self.plot, background=self.background, **self.kwargs)
+        attribute_plot = AttributePlot(attribute, self.buffer_size, plot=self.plot,
+                                       background=self.background, **self.kwargs)
         self.layout().addWidget(attribute_plot)
         attribute.attach_callback(lambda _: attribute_plot.update(), max_update_rate=self.max_update_rate,
                                   key_filter=VALUE)
