@@ -17,8 +17,8 @@ class LockButton(QPushButton):
         self.setStyleSheet(u"QPushButton:flat {   border: none; }")
         self.setText(u"")
         icon = QIcon()
-        icon.addPixmap(QPixmap(u":/icons/icons/unlock.png"), QIcon.Normal, QIcon.Off)
-        icon.addPixmap(QPixmap(u":/icons/icons/lock.png"), QIcon.Normal, QIcon.On)
+        icon.addPixmap(QPixmap(u":/icons/icons/radio_off.png"), QIcon.Normal, QIcon.Off)
+        icon.addPixmap(QPixmap(u":/icons/icons/radio_on.png"), QIcon.Normal, QIcon.On)
         self.setIcon(icon)
         self.setIconSize(QSize(16, 16))
         self.setCheckable(True)
