@@ -232,7 +232,7 @@ class MacroWidget(QWidget, YamlSerializable):
         return repeat_widget
 
     def _show_retry_widget(self, row):
-        default_value = self.config.get("retry", 0)
+        default_value = self.config.get("retry_count", 0)
         retry_widget = AttributeDisplayWidget("Retry step",
                                               Attribute(default_value=int(default_value), default_type=np.uint32,
                                                         min_value=0,
