@@ -73,6 +73,8 @@ class ModelTableModel(QAbstractTableModel):
     def flags(self, index):
         return QtCore.Qt.ItemIsEditable | QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable
 
+    def get_neighbour_steps(self, ref_profile_index, ref_profile_step_index):
+        return None, None
 
 class ModelTable(QWidget, Ui_Form):
 
