@@ -91,14 +91,14 @@ class MacroToolWidget(Ui_Form, DeviceWidget):
 
         self.combobox_template.addItems(self.loaded_templates.keys())
         self.combobox_template.addItem(CUSTOM_TEMPLATE)
-
+        self.combobox_template.setCurrentText(CUSTOM_TEMPLATE)
         self.combobox_template.blockSignals(False)
-        self.template_selected(self.combobox_template.currentText())
+        self.template_selected(CUSTOM_TEMPLATE)
 
     @pyqtSlot()
     def slot_set_macro_prefix(self):
-        macro_preifx = self.device.get_value(ATTR_MACRO_PREFIX)
-        self.label_new_macro.setText(u"Create new {}".format(macro_preifx))
+        macro_prefix = self.device.get_value(ATTR_MACRO_PREFIX)
+        self.label_new_macro.setText(u"Create new {}".format(macro_prefix))
 
     @pyqtSlot()
     def slot_set_running_macros(self):
@@ -151,7 +151,7 @@ class MacroToolWidget(Ui_Form, DeviceWidget):
 
     def get_template_meta(self):
         """
-        Go thru all widgets in template and export it's meta.
+        Go through all widgets in template and export it's meta.
         :return: list of meta data describing template
         """
         meta = []
