@@ -126,6 +126,18 @@ class MacroServer(Device):
             })
         return macros_meta_list
 
+    @expose_method()
+    def broadcast_macro_header(self):
+        """
+        This is just a patch function to support Onda.
+        TODO: remove this function after Onda is properly communicating with Kamzik3
+        :return:
+        """
+        for running_macro in self.running_macros.values():
+            attribute_object = running_macro.macro_logger[ATTR_HEADER]
+            header = "{}.{}".format(attribute_object.attribute_id, VALUE)
+            kamzik3.session.publisher.push_message(header, running_macro.macro_logger.get_value(ATTR_HEADER))
+
     @expose_method({"macro_id": "ID of uploaded macro"})
     def get_macro_template(self, macro_id):
         try:
