@@ -15,7 +15,6 @@ from kamzik3.macro.step import StepSetpointNumerical
 
 class Scan(StepGenerator):
     first_step_at = 0
-    resolved = False
 
     def __init__(self, common_id, start_point, end_point, steps_count, step_class=StepSetpointNumerical,
                  step_attributes=None, repeat_count=0, random_deviation=units.Quantity(0, "percent"),
@@ -25,8 +24,6 @@ class Scan(StepGenerator):
         assert isinstance(end_point, units.Quantity)
         assert isinstance(wait_after, units.Quantity)
         assert steps_count > 0
-        self.scanner = scanner
-        self.scanner_attributes = scanner_attributes
         self.return_back = return_back
         self.step_index = 0
         self.start_point = start_point
@@ -52,7 +49,8 @@ class Scan(StepGenerator):
         attribute = kamzik3.session.get_device(
             self.step_attributes["device_id"]).get_attribute(self.step_attributes["attribute"])
         self.initial_value_of_attribute = attribute.value()
-        super(Scan, self).__init__(common_id, repeat_count, wait_after, retry_count, trigger_log, on_warning, timeout)
+        super(Scan, self).__init__(common_id, repeat_count, wait_after, retry_count, trigger_log, on_warning, timeout,
+                                   scanner=scanner, scanner_attributes=scanner_attributes)
 
     def set_steps_count(self, steps_count):
         """
