@@ -137,7 +137,6 @@ class Publisher():
             self.zmq_context = zmq.Context.instance()
         self.host = host
         self.port = port
-        self.publisher_events = {}
         self.messages_queue = deque()
         self._init_socket()
 
@@ -150,36 +149,18 @@ class Publisher():
         timeout = 0.005
         self.running = True
         while self.running:
-            publish_time = perf_counter_ns()
             while self.messages_queue:
-                header, message, min_timeout = self.messages_queue.popleft()
-                last_message_event = self.publisher_events.get(header, None)
-                if (last_message_event is None) or (publish_time - last_message_event[0]) >= min_timeout:
-                    self._publish_message(header, message)
-                    self.publisher_events[header] = [publish_time, [header, None, min_timeout]]
-                else:
-                    last_message_event[1][1] = message
-
-            for event in list(self.publisher_events.values()):
-                if (publish_time - event[0]) >= event[1][2]:
-                    if event[1][1] is not None:
-                        self._publish_message(event[1][0], event[1][1])
-                        self.publisher_events[event[1][0]] = [publish_time, [event[1][0], None, event[1][2]]]
-                    else:
-                        del self.publisher_events[event[1][0]]
-
-            elapsed_ns = (perf_counter_ns() - publish_time) * 1e-9
-            sleep_timeout = timeout - elapsed_ns
-            sleep(sleep_timeout if sleep_timeout > 0 else 0)
+                self._publish_message(*self.messages_queue.popleft())
+            sleep(timeout)
 
     def _publish_message(self, header, message):
         raise NotImplementedError()
 
-    def push_message(self, header, message, token=None, min_timeout=100e6):
+    def push_message(self, header, message, token=None):
         try:
             if token is not None:
                 header += u"." + str(token)
-            self.messages_queue.append((header, message, min_timeout))
+            self.messages_queue.append((header, message))
         except TypeError:
             self.logger.exception(u"Error pushing message to client")
 
